Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(140)

Unified Diff: runtime/vm/flow_graph_type_propagator.cc

Issue 2994113003: [vm] Rename *MintOp to *Int64Op to emphasis that they operate on unboxed values. (Closed)
Patch Set: il-printer Created 3 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/vm/flow_graph_range_analysis.cc ('k') | runtime/vm/il_printer.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/flow_graph_type_propagator.cc
diff --git a/runtime/vm/flow_graph_type_propagator.cc b/runtime/vm/flow_graph_type_propagator.cc
index c86ebb32cd90299aa91d29231dad071371312445..7a2fa75290324bc36ff2c952d9dd5a1e9a014fb0 100644
--- a/runtime/vm/flow_graph_type_propagator.cc
+++ b/runtime/vm/flow_graph_type_propagator.cc
@@ -1120,17 +1120,17 @@ CompileType ConstraintInstr::ComputeType() const {
return CompileType::FromCid(kSmiCid);
}
// Note that MintOp may produce Smi-s as result of an
// appended BoxInt64Instr node.
-CompileType BinaryMintOpInstr::ComputeType() const {
+CompileType BinaryInt64OpInstr::ComputeType() const {
return CompileType::Int();
}
-CompileType ShiftMintOpInstr::ComputeType() const {
+CompileType ShiftInt64OpInstr::ComputeType() const {
return CompileType::Int();
}
-CompileType UnaryMintOpInstr::ComputeType() const {
+CompileType UnaryInt64OpInstr::ComputeType() const {
return CompileType::Int();
}
@@ -1330,7 +1330,7 @@ CompileType UnboxInstr::ComputeType() const {
case kUnboxedInt32x4:
return CompileType::FromCid(kInt32x4Cid);
- case kUnboxedMint:
+ case kUnboxedInt64:
return CompileType::Int();
default:
« no previous file with comments | « runtime/vm/flow_graph_range_analysis.cc ('k') | runtime/vm/il_printer.cc » ('j') | no next file with comments »
@@ -1120,17 +1120,17 @@ CompileType ConstraintInstr::ComputeType() const {
return CompileType::FromCid(kSmiCid);
}
-// Note that MintOp may produce Smi-s as result of an
+// Note that Int64Op may produce Smi-s as result of an
// appended BoxInt64Instr node.

Powered by Google App Engine
This is Rietveld 408576698